@@ -1021,7 +1021,7 @@ function process_input($field) {
 		return null;
 	}
 	if ($function == "orig") {
-		return ($field["on_update"] == "CURRENT_TIMESTAMP" ? idf_escape($field["field"]) : false);
+		return (preg_match('~^CURRENT_TIMESTAMP~i', $field["on_update"]) ? idf_escape($field["field"]) : false);
 	}
 	if ($function == "NULL") {
 		return "NULL";
@@ -1419,7 +1419,7 @@ function edit_form($TABLE, $fields, $row, $update) {
 	if (!$fields) {
 		echo "<p class='error'>" . lang('You have no privileges to update this table.') . "\n";
 	} else {
-		echo "<table cellspacing='0'>" . script("qsl('table').onkeydown = editingKeydown;");
+		echo "<table cellspacing='0' class='layout'>" . script("qsl('table').onkeydown = editingKeydown;");
 
 		foreach ($fields as $name => $field) {
 			echo "<tr><th>" . $adminer->fieldName($field);
@@ -1445,12 +1445,12 @@ function edit_form($TABLE, $fields, $row, $update) {
 			}
 			$function = ($_POST["save"]
 				? (string) $_POST["function"][$name]
-				: ($update && $field["on_update"] == "CURRENT_TIMESTAMP"
+				: ($update && preg_match('~^CURRENT_TIMESTAMP~i', $field["on_update"])
 					? "now"
 					: ($value === false ? null : ($value !== null ? '' : 'NULL'))
 				)
 			);
-			if (preg_match("~time~", $field["type"]) && $value == "CURRENT_TIMESTAMP") {
+			if (preg_match("~time~", $field["type"]) && preg_match('~^CURRENT_TIMESTAMP~i', $value)) {
 				$value = "";
 				$function = "now";
 			}
